import cpuinfo

def get_cpu_info(to_display=False, detailed=False):
    info = cpuinfo.get_cpu_info()
    if to_display:
        to_display = get_cpu_info_strings(info, detailed)
        for line in to_display:
            print line
    return info

def get_cpu_info_strings(info, detailed):
    to_display = []
    not_relevant = ["flags", "model", "extended_model", "l2_cache_line_size", "family", "l2_cache_associativity",
                    "hz_advertised_raw", "hz_actual_raw", "raw_arch_string", "stepping", "cpuinfo_version",
                    "vendor_id"]

    for key, value in info.iteritems():
        sugar_key = key.replace("_", " ")
        if key not in not_relevant and not detailed:
            to_display.append(sugar_key + ": " + str(value))
        elif detailed:
            to_display.append(sugar_key + ": " + str(value))
    return to_display



import threading
import random
import time
import signal
from multiprocessing import Pool

def load_cpu_func(x):
    nb_op = 0
    start = time.time()
    spent = 0
    while spent < 1:
        #print "a"
        spent = time.time() - start
        x * x
        nb_op += 1
    return nb_op

def load_cpu_until_death(x):
    while True:
        x * x

def launch_cpu_load(display, standalone, no_of_cpu_to_be_consumed=1):
    print "Loading CPU..."
    p = Pool(processes=no_of_cpu_to_be_consumed)
    if(standalone):
        while True:
            perf_list = p.map_async(load_cpu_func, range(no_of_cpu_to_be_consumed)).get(no_of_cpu_to_be_consumed + 1)
            op_per_sec = 0
            for nb_op in perf_list:
                op_per_sec += nb_op
            if(display):
                print ("%i operation per second") % (op_per_sec)
    else:
        p.map_async(load_cpu_until_death, range(no_of_cpu_to_be_consumed))


from setuptools import setup

setup(name='cpu_monitor',
      packages=['cpu_monitor'],
      version='0.2',
      description='Cpu monitoring and burning tool',
      author='yotabits',
      author_email='tkostas75@gmail.com',
      license='MIT',
      url='https://github.com/yotabits/cpu_monitor',
      #download_url='https://github.com/yotabits/cpu_monitor/archive/0.1.tar.gz',
      scripts=['bin/cpu_monitor'],
      keywords='monitoring cpu',
      install_requires=[
          'py-cpuinfo',
          'plotly',
          'colorama',
          'dash',
          'dash_renderer',
          'dash_core_components',
          'dash_html_components'
      ],
        classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Build Tools',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 2.7',
        ],
      zip_safe=False)
